@@ -1,4 +1,4 @@
-__all__ = ('UserPoint', 'SendPasswordPoint',)
+__all__ = ('UserPoint', 'SendPasswordPoint')
 
 from phonenumber_field.serializerfields import PhoneNumberField
 
