@@ -12,6 +12,8 @@ class IndicatorFillingTaskCreateContract(Contract):
 
 class IndicatorDescriptionReadContract(Contract):
     name = serializers.CharField(max_length=128)
+    label = serializers.CharField(max_length=128)
+    description = serializers.CharField(max_length=1024)
 
 
 class IndicatorReadContract(Contract):
@@ -22,7 +24,7 @@ class IndicatorReadContract(Contract):
         (GOOD, GOOD),
     )
     created = serializers.DateTimeField()
-    description = IndicatorFillingTaskCreateContract()
+    description = IndicatorDescriptionReadContract()
     value = serializers.IntegerField(min_value=0)
     rate = serializers.ChoiceField(choices=RATE_CHOICES)
     recommendation = serializers.CharField(max_length=1024)
