@@ -1,4 +1,4 @@
-__all__ = ('PartnerPayoutPoint', 'PartnerRevenuePoint', 'PartnerBalancePoint')
+__all__ = ('PartnerPayoutPoint', 'PartnerRevenuePoint', 'PartnerBalancePoint', 'ChargebackPoint')
 
 from expressmoney.api import *
 
@@ -26,6 +26,11 @@ class PartnerBalanceReadContract(PartnerPayoutReadContract):
     pass
 
 
+class ChargebackCreateContract(Contract):
+    amount = serializers.DecimalField(max_digits=16, decimal_places=0)
+    bank_card_id = serializers.IntegerField(min_value=1)
+
+
 class PartnerPayoutID(ID):
     _service = SERVICE
     _app = APP
@@ -44,6 +49,12 @@ class PartnerBalanceID(ID):
     _view_set = 'partner_balance'
 
 
+class ChargebackID(ID):
+    _service = SERVICE
+    _app = APP
+    _view_set = 'chargeback'
+
+
 class PartnerPayoutPoint(ListPointMixin, CreatePointMixin, ContractPoint):
     _point_id = PartnerPayoutID()
     _create_contract = PartnerPayoutCreateContract
@@ -61,3 +72,8 @@ class PartnerBalancePoint(ListPointMixin, ContractPoint):
     _point_id = PartnerBalanceID()
     _read_contract = PartnerBalanceReadContract
     _sort_by = 'created'
+
+
+class ChargebackPoint(CreatePointMixin, ContractPoint):
+    _point_id = ChargebackID()
+    _create_contract = ChargebackCreateContract
