@@ -9,9 +9,11 @@ class BankCardPaymentCreateContract(Contract):
     amount = serializers.DecimalField(max_digits=16, decimal_places=0, min_value=1)
     withdraw = serializers.BooleanField()
     bank_card = serializers.IntegerField(min_value=1)
+    order_id = serializers.IntegerField()
+    order_type = serializers.CharField(max_length=128)
 
 
-class BankCardPaymentResponseContract(BankCardPaymentCreateContract):
+class BankCardPaymentResponseContract(Contract):
     id = serializers.IntegerField(min_value=1)
     created = serializers.DateTimeField()
 
