@@ -1,7 +1,6 @@
 __all__ = ('CreditScoringTaskPoint',)
 
 from expressmoney.api import *
-from expressmoney.viewflow import result
 
 
 SERVICE = 'profiles'
@@ -9,6 +8,14 @@ APP = 'credit_scoring'
 
 
 class CreditScoringTaskReadContract(Contract):
+    EMPTY = 'EMPTY'
+    SUCCESS = 'SCS'
+    FAILURE = 'FAIL'
+    RESULT_CHOICES = (
+        (EMPTY, EMPTY),
+        (FAILURE, FAILURE),
+        (SUCCESS, SUCCESS),
+    )
     RU = 'RU'
     COUNTRY_CHOICES = (
         (RU, RU),
@@ -17,7 +24,7 @@ class CreditScoringTaskReadContract(Contract):
     created = serializers.DateTimeField()
     user_id = serializers.IntegerField(min_value=1)
     country = serializers.ChoiceField(choices=COUNTRY_CHOICES)
-    result = serializers.ChoiceField(choices=result.RESULT_CHOICES)
+    result = serializers.ChoiceField(choices=RESULT_CHOICES)
     score = serializers.DecimalField(max_digits=3, decimal_places=2, allow_null=True)
     comment = serializers.CharField(max_length=1024, allow_blank=True)
 
